accounting.report.period package
================================

Submodules
----------

accounting.report.period.chooser module
---------------------------------------

.. automodule:: accounting.report.period.chooser
   :members:
   :undoc-members:
   :show-inheritance:

accounting.report.period.description module
-------------------------------------------

.. automodule:: accounting.report.period.description
   :members:
   :undoc-members:
   :show-inheritance:

accounting.report.period.month\_end module
------------------------------------------

.. automodule:: accounting.report.period.month_end
   :members:
   :undoc-members:
   :show-inheritance:

accounting.report.period.parser module
--------------------------------------

.. automodule:: accounting.report.period.parser
   :members:
   :undoc-members:
   :show-inheritance:

accounting.report.period.period module
--------------------------------------

.. automodule:: accounting.report.period.period
   :members:
   :undoc-members:
   :show-inheritance:

accounting.report.period.shortcuts module
-----------------------------------------

.. automodule:: accounting.report.period.shortcuts
   :members:
   :undoc-members:
   :show-inheritance:

accounting.report.period.specification module
---------------------------------------------

.. automodule:: accounting.report.period.specification
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: accounting.report.period
   :members:
   :undoc-members:
   :show-inheritance:
